@@ -15,7 +15,7 @@ class Expressions:
         for line in tsv_str.split('\n'):
             line = line.strip()
 
-            if line.startswith('#'):
+            if line.startswith('#') or not len(line):
                 continue
 
             tokens = line.split('\t')
