@@ -8,6 +8,7 @@ from vatis.asr_commons.domain import Word
 
 from vatis.asr_commons.config.logging import get_logger
 from vatis.asr_commons.custom_models import Model
+from vatis.asr_commons.domain.find_replace import FindReplaceConfig
 
 logger = get_logger(__name__)
 
@@ -38,6 +39,7 @@ class TranscriptionRequest:
                  speakers_number: Optional[int] = None,
                  multi_channels: bool = False,
                  created_date: datetime.datetime = None,
+                 find_replace_expressions: List[FindReplaceConfig] = None,
                  **kwargs):
         assert file_uid is not None
         assert file_path is not None
@@ -66,6 +68,7 @@ class TranscriptionRequest:
         self.speakers_number: Optional[int] = speakers_number
         self.multi_channels: bool = multi_channels
         self.created_date: datetime.datetime = created_date if created_date is not None else datetime.datetime.utcnow()
+        self.find_replace_expressions: List[FindReplaceConfig] = find_replace_expressions
 
         if isinstance(hotwords, list):
             self.hotwords = hotwords
